==> v0.6.0.zip: akkounts/app/models/setting.rb <==
# RailsSettings Model
class Setting < RailsSettings::Base
  cache_prefix { "v1" }

  field :accounts_domain, type: :string,
    default: ENV["AKKOUNTS_DOMAIN"].presence

  #
  # Internal services
  #

  field :redis_url, type: :string, readonly: true,
    default: ENV["REDIS_URL"] || "redis://localhost:6379/0"

  #
  # Registrations
  #

  field :reserved_usernames, type: :array, default: %w[
    account accounts donations mail webmaster support
  ]

  #
  # XMPP
  #

  field :xmpp_default_rooms, type: :array, default: []
  field :xmpp_autojoin_default_rooms, type: :boolean, default: false

  #
  # Sentry
  #

  field :sentry_enabled, type: :boolean, readonly: true,
    default: (ENV["SENTRY_DSN"].present?.to_s || false)

  #
  # Discourse
  #

  field :discourse_public_url, type: :string, readonly: true,
    default: ENV["DISCOURSE_PUBLIC_URL"].presence

  field :discourse_enabled, type: :boolean,
    default: (ENV["DISCOURSE_PUBLIC_URL"].present?.to_s || false)

  field :discourse_connect_secret, type: :string, readonly: true,
    default: ENV["DISCOURSE_CONNECT_SECRET"].presence

  #
  # ejabberd
  #

  field :ejabberd_enabled, type: :boolean,
    default: (ENV["EJABBERD_API_URL"].present?.to_s || false)

  field :ejabberd_api_url, type: :string, readonly: true,
    default: ENV["EJABBERD_API_URL"].presence

  field :ejabberd_admin_url, type: :string, readonly: true,
    default: ENV["EJABBERD_ADMIN_URL"].presence

  field :ejabberd_buddy_roster, type: :string,
    default: "Buddies"

  #
  # Gitea
  #

  field :gitea_public_url, type: :string, readonly: true,
    default: ENV["GITEA_PUBLIC_URL"].presence

  field :gitea_enabled, type: :boolean,
    default: (ENV["GITEA_PUBLIC_URL"].present?.to_s || false)

  #
  # Lightning Network
  #

  field :lndhub_api_url, type: :string, readonly: true,
    default: ENV["LNDHUB_API_URL"].presence

  field :lndhub_enabled, type: :boolean,
    default: (ENV["LNDHUB_API_URL"].present?.to_s || false)

  field :lndhub_admin_enabled, type: :boolean,
    default: (ENV["LNDHUB_ADMIN_UI"] || false)

  field :lndhub_public_key, type: :string, readonly: true,
    default: (ENV["LNDHUB_PUBLIC_KEY"] || "")

  field :lndhub_keysend_enabled, type: :boolean,
    default: -> { self.lndhub_public_key.present?.to_s || false }

  #
  # Mastodon
  #

  field :mastodon_public_url, type: :string, readonly: true,
    default: ENV["MASTODON_PUBLIC_URL"].presence

  field :mastodon_enabled, type: :boolean,
    default: (ENV["MASTODON_PUBLIC_URL"].present?.to_s || false)

  #
  # MediaWiki
  #

  field :mediawiki_public_url, type: :string, readonly: true,
    default: ENV["MEDIAWIKI_PUBLIC_URL"].presence

  field :mediawiki_enabled, type: :boolean,
    default: (ENV["MEDIAWIKI_PUBLIC_URL"].present?.to_s || false)

  #
  # Nostr
  #

  field :nostr_enabled, type: :boolean, default: true

  #
  # RemoteStorage
  #

  field :remotestorage_enabled, type: :boolean,
    default: (ENV["RS_STORAGE_URL"].present?.to_s || false)

  field :rs_storage_url, type: :string,
    default: ENV["RS_STORAGE_URL"].presence
end

==> v0.8.0.zip: akkounts/app/models/setting.rb <==
# RailsSettings Model
class Setting < RailsSettings::Base
  cache_prefix { "v1" }

  field :primary_domain, type: :string,
    default: ENV["PRIMARY_DOMAIN"].presence

  field :accounts_domain, type: :string,
    default: ENV["AKKOUNTS_DOMAIN"].presence

  #
  # Internal services
  #

  field :redis_url, type: :string,
    default: ENV["REDIS_URL"] || "redis://localhost:6379/0"

  #
  # Registrations
  #

  field :reserved_usernames, type: :array, default: %w[
    account accounts donations mail webmaster support
  ]

  #
  # XMPP
  #

  field :xmpp_default_rooms, type: :array, default: []
  field :xmpp_autojoin_default_rooms, type: :boolean, default: false
  field :xmpp_notifications_from_address, type: :string, default: primary_domain

  #
  # Sentry
  #

  field :sentry_enabled, type: :boolean, readonly: true,
    default: (ENV["SENTRY_DSN"].present?.to_s || false)

  #
  # Discourse
  #

  field :discourse_public_url, type: :string,
    default: ENV["DISCOURSE_PUBLIC_URL"].presence

  field :discourse_enabled, type: :boolean,
    default: (ENV["DISCOURSE_PUBLIC_URL"].present?.to_s || false)

  field :discourse_connect_secret, type: :string,
    default: ENV["DISCOURSE_CONNECT_SECRET"].presence

  #
  # Drone CI
  #

  field :droneci_public_url, type: :string,
    default: ENV["DRONECI_PUBLIC_URL"].presence

  field :droneci_enabled, type: :boolean,
    default: (ENV["DRONECI_PUBLIC_URL"].present?.to_s || false)

  #
  # ejabberd
  #

  field :ejabberd_enabled, type: :boolean,
    default: (ENV["EJABBERD_API_URL"].present?.to_s || false)

  field :ejabberd_api_url, type: :string,
    default: ENV["EJABBERD_API_URL"].presence

  field :ejabberd_admin_url, type: :string,
    default: ENV["EJABBERD_ADMIN_URL"].presence

  field :ejabberd_buddy_roster, type: :string,
    default: "Buddies"

  #
  # Gitea
  #

  field :gitea_public_url, type: :string,
    default: ENV["GITEA_PUBLIC_URL"].presence

  field :gitea_enabled, type: :boolean,
    default: (ENV["GITEA_PUBLIC_URL"].present?.to_s || false)

  #
  # Lightning Network
  #

  field :lndhub_api_url, type: :string,
    default: ENV["LNDHUB_API_URL"].presence

  field :lndhub_enabled, type: :boolean,
    default: (ENV["LNDHUB_API_URL"].present?.to_s || false)

  field :lndhub_admin_enabled, type: :boolean,
    default: (ENV["LNDHUB_ADMIN_UI"] || false)

  field :lndhub_public_key, type: :string,
    default: (ENV["LNDHUB_PUBLIC_KEY"] || "")

  field :lndhub_keysend_enabled, type: :boolean,
    default: -> { self.lndhub_public_key.present?.to_s || false }

  #
  # Mastodon
  #

  field :mastodon_public_url, type: :string,
    default: ENV["MASTODON_PUBLIC_URL"].presence

  field :mastodon_enabled, type: :boolean,
    default: (ENV["MASTODON_PUBLIC_URL"].present?.to_s || false)

  field :mastodon_address_domain, type: :string,
    default: ENV["MASTODON_ADDRESS_DOMAIN"].presence || self.primary_domain

  #
  # MediaWiki
  #

  field :mediawiki_public_url, type: :string,
    default: ENV["MEDIAWIKI_PUBLIC_URL"].presence

  field :mediawiki_enabled, type: :boolean,
    default: (ENV["MEDIAWIKI_PUBLIC_URL"].present?.to_s || false)

  #
  # Nostr
  #

  field :nostr_enabled, type: :boolean, default: true

  #
  # RemoteStorage
  #

  field :remotestorage_enabled, type: :boolean,
    default: (ENV["RS_STORAGE_URL"].present?.to_s || false)

  field :rs_storage_url, type: :string,
    default: ENV["RS_STORAGE_URL"].presence

  field :rs_redis_url, type: :string,
    default: ENV["RS_REDIS_URL"] || "redis://localhost:6379/1"
end
